==> kdesdk-4.1.0.tar.bz2: kdesdk-4.1.0/lokalize/src/prefs/prefs.h <==
/* ****************************************************************************
  This file is part of KAider

  Copyright (C) 2007 by Nick Shaforostoff <shafff@ukr.net>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

  In addition, as a special exception, the copyright holders give
  permission to link the code of this program with any edition of
  the Qt library by Trolltech AS, Norway (or with modified versions
  of Qt that use the same license as Qt), and distribute linked
  combinations including the two.  You must obey the GNU General
  Public License in all respects for all of the code used other than
  Qt. If you modify this file, you may extend this exception to
  your version of the file, but you are not obligated to do so.  If
  you do not wish to do so, delete this exception statement from
  your version.

**************************************************************************** */

#ifndef SETTINGSCONTROLLER_H
#define SETTINGSCONTROLLER_H

#include <QLineEdit>
class KEditListBox;

class SettingsController: public QObject
{
    Q_OBJECT

public:
    SettingsController();
    ~SettingsController();

public slots:
    void slotSettings();

    void projectOpen(QString path=QString());
    void projectCreate();
    void projectConfigure();
    void reflectRelativePathsHack();

signals:
    void generalSettingsChanged();

private:
    KEditListBox* m_scriptsRelPrefWidget; //HACK to get relative filenames in the project file
    KEditListBox* m_scriptsPrefWidget;

private:
    static SettingsController* _instance;
    static void cleanupSettingsController();
public:
    static SettingsController* instance();

};

/**
 * helper widget to save relative paths in project file
 * (so it could be published in svn)
 */
class RelPathSaver: public QLineEdit
{
Q_OBJECT
public:
    RelPathSaver(QWidget* p):QLineEdit(p){}
public slots:
    void setText ( const QString & );
};



#endif

==> kdesdk-4.2.3.tar.bz2: kdesdk-4.2.3/lokalize/src/prefs/prefs.h <==
/* ****************************************************************************
  This file is part of KAider

  Copyright (C) 2007 by Nick Shaforostoff <shafff@ukr.net>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

  In addition, as a special exception, the copyright holders give
  permission to link the code of this program with any edition of
  the Qt library by Trolltech AS, Norway (or with modified versions
  of Qt that use the same license as Qt), and distribute linked
  combinations including the two.  You must obey the GNU General
  Public License in all respects for all of the code used other than
  Qt. If you modify this file, you may extend this exception to
  your version of the file, but you are not obligated to do so.  If
  you do not wish to do so, delete this exception statement from
  your version.

**************************************************************************** */

#ifndef SETTINGSCONTROLLER_H
#define SETTINGSCONTROLLER_H

#include <QLineEdit>
class KEditListBox;

/**
 * Singleton that manages cfgs for Lokalize and projects
 */
class SettingsController: public QObject
{
    Q_OBJECT

public:
    SettingsController();
    ~SettingsController();

public slots:
    void slotSettings();

    void projectOpen(QString path=QString());
    void projectCreate();
    void projectConfigure();
    void reflectRelativePathsHack();

signals:
    void generalSettingsChanged();

private:
    KEditListBox* m_scriptsRelPrefWidget; //HACK to get relative filenames in the project file
    KEditListBox* m_scriptsPrefWidget;

private:
    static SettingsController* _instance;
    static void cleanupSettingsController();
public:
    static SettingsController* instance();

};

/**
 * helper widget to save relative paths in project file,
 * thus allowing its publishing in e.g. svn
 */
class RelPathSaver: public QLineEdit
{
Q_OBJECT
public:
    RelPathSaver(QWidget* p):QLineEdit(p){}
public slots:
    void setText ( const QString & );
};



#endif
